// puddinq map geo
// License: http://www.wtfpl.net/
// Version: v0.0.1

var pud_map_geo;

(function ($, root, undefined) {

    'use strict';

    /*********************
     *  Document ready
     ********************/

    jQuery(document).ready(function() {


        /* kadaster*/


        var kadasterSource = new ol.source.Vector({
            format: new ol.format.GeoJSON(),
            url: function(extent) {
                return 'https://wfs.haarlem.nl/ows?service=WFS&' +
                    'version=1.1.0&request=GetFeature&typename=gemeentehaarlem:kadastrale_kaart&' +
                    'outputFormat=application/json&srsname=EPSG:3857&' +
                    'bbox=' + extent.join(',') + ',EPSG:3857';
            },
            strategy: ol.loadingstrategy.bbox
        });

        var kadaster = new ol.layer.Vector({
            source: kadasterSource,
            style: new ol.style.Style({
                stroke: new ol.style.Stroke({
                    color: 'yellow',
                    width: 2,
                    lineDash: [4,4]
                })
            })
        });

        /* gebouwen */

        var pandenSource = new ol.source.Vector({
            format: new ol.format.GeoJSON(),
            url: function(extent) {
                return 'https://geodata.nationaalgeoregister.nl/bag/wfs?' +
                    'version=2.0.0&request=GetFeature&typename=pand' +
                    '&outputFormat=application/json&srsname=EPSG:3857&' +
                    'bbox=' + extent.join(',') + ',EPSG:3857';
            },
            strategy: ol.loadingstrategy.bbox
        });

        var panden = new ol.layer.Vector({
            source: pandenSource,
            style: new ol.style.Style({
                stroke: new ol.style.Stroke({
                    color: 'black',
                    width: 2
                }),
                fill: new ol.style.Fill({
                    color: 'rgba(255, 255, 0, 0.1)'
                })
            })
        });

        /* buurten */

        var buurtSource = new ol.source.Vector({
            url: 'https://wfs.haarlem.nl/ows?service=WFS&version=2.0.0&request=GetFeature&typename=buurt&outputFormat=application/json&srsname=EPSG:3857',
            format: new ol.format.GeoJSON()
        });

        var buurt = new ol.layer.Vector({
            source: buurtSource,
            style: new ol.style.Style({
                stroke: new ol.style.Stroke({
                    color: '#319FD3',
                    width: 2
                }),
                image: new ol.style.Circle({
                    radius: 3,
                    fill: new ol.style.Fill({color: 'white'})
                })
            })
        });


        /* gemeente grens */


        var gemeenteSource = new ol.source.Vector({
            format: new ol.format.GeoJSON(),
            url: function(extent) {
                return 'https://wfs.haarlem.nl/ows?service=WFS&' +
                    'version=1.1.0&request=GetFeature&typename=gemeentehaarlem:gemeentegrens&' +
                    'outputFormat=application/json&srsname=EPSG:3857&' +
                    'bbox=' + extent.join(',') + ',EPSG:3857';
            },
            strategy: ol.loadingstrategy.bbox
        });

        var gemeente = new ol.layer.Vector({
            source: gemeenteSource,
            style: new ol.style.Style({
                stroke: new ol.style.Stroke({
                    color: 'red',
                    width: 2
                })
            })
        });



        /* Stadsdelen*/


        var stadsdelenSource = new ol.source.Vector({
            format: new ol.format.GeoJSON(),
            url: function(extent) {
                return 'https://wfs.haarlem.nl/ows?service=WFS&version=2.0.0&request=GetFeature&typename=stadsdeel&outputFormat=application/json&srsname=EPSG:3857&' +
                    'bbox=' + extent.join(',') + ',EPSG:3857';
            },
            strategy: ol.loadingstrategy.bbox
        });
        var stadsdelen = new ol.layer.Vector({
            source: stadsdelenSource,
            style: new ol.style.Style({
                stroke: new ol.style.Stroke({
                    color: 'red',
                    width: 1
                })
            })
        });

        /* Woonplaats grens */


        var woonplaatsSource = new ol.source.Vector({
            format: new ol.format.GeoJSON(),
            url: function(extent) {
                return 'https://geodata.nationaalgeoregister.nl/bag/wfs?' +
                    'version=2.0.0&request=GetFeature&typename=woonplaats' +
                    '&outputFormat=application/json&srsname=EPSG:3857&' +
                    'bbox=' + extent.join(',') + ',EPSG:3857';
            },
            strategy: ol.loadingstrategy.bbox
        });


        var woonplaats = new ol.layer.Vector({
            source: woonplaatsSource,
            style: new ol.style.Style({
                stroke: new ol.style.Stroke({
                    color: 'black',
                    width: 2
                })
            })
        });

        var wegenSource = new ol.source.Vector({
            format: new ol.format.GeoJSON(),
            url: function(extent) {
                return 'https://geodata.nationaalgeoregister.nl/nwbwegen/wfs?' +
                    'version=2.0.0&request=GetFeature&typename=nwbwegen:wegvakken' +
                    '&outputFormat=application/json&srsname=EPSG:3857&' +
                    'bbox=' + extent.join(',') + ',EPSG:3857';
            },
            strategy: ol.loadingstrategy.bbox
        });


        var wegen = new ol.layer.Vector({
            source: wegenSource,
            style: new ol.style.Style({
                stroke: new ol.style.Stroke({
                    color: 'green',
                    width: 2
                })
            })
        });


        /*
         *  Map
         */

        var raster = new ol.layer.Tile({
            source: new ol.source.BingMaps({
                imagerySet: 'Road',
                key: 'AuR-3BKnYGj7anf74lsV5BHsvdcU1hSCKMwYWXigQ1LrJEk19ywBiFp8Jty1i_6W'
            })
        });

        var longitude = parseFloat(pud_map_geo.long);
        var latitude = parseFloat(pud_map_geo.latt);
        var center = ol.proj.transform([longitude, latitude], 'EPSG:4326','EPSG:3857');

        var map = new ol.Map({
            layers: [raster, kadaster, wegen, panden, buurt, stadsdelen, woonplaats, gemeente],
            target: document.getElementById('map'),
            view: new ol.View({
                center: center,
                maxZoom: 19,
                zoom: 17
            })
        });


        /*
         * Map events
         */


        /* input toggle layers*/
        function bindInputs(layerid, layer) {
            var visibilityInput = $(layerid + ' input.visible');
            visibilityInput.on('change', function() {
                layer.setVisible(this.checked);
            });
            visibilityInput.prop('checked', layer.getVisible());
        }

        map.getLayers().forEach(function(layer, i) {
            bindInputs('#layer' + i, layer);
        });

    });

})(jQuery, this);
